# Plasma Cylinder

[![code testing](https://github.com/grintor/Hello-Wolrd-CI/actions/workflows/testing.yaml/badge.svg)](https://github.com/grintor/Hello-World-CI/actions/workflows/testing.yaml)
[![CodeQL](https://github.com/grintor/Hello-Wolrd-CI/actions/workflows/codeql.yaml/badge.svg)](https://github.com/grintor/Hello-Wolrd-CI/actions/workflows/codeql.yaml)
[![code coverage](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/grintor/Hello-Wolrd-CI/main/.repo-shields/covered_shield.json)](.repo-reports/coverage.txt)
[![code quality](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/grintor/Hello-Wolrd-CI/main/.repo-shields/quality_shield.json)](.repo-reports/pylint-report.txt)
[![PyPI version](https://badge.fury.io/py/cylinder.svg)](https://badge.fury.io/py/cylinder)

Plasma Cylinder is a web application framework and webserver built atop [flask](https://pypi.org/project/Flask/) and
[waitress](https://pypi.org/project/waitress/). It is designed to be production-ready, extraordinarily easy to learn,
and to encourage a project layout which facilitates collaboration.

For additional information please review the documentation at
[plasmacan.github.io/cylinder](https://plasmacan.github.io/cylinder/)
